summaryrefslogtreecommitdiffstats
path: root/juk/tag.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'juk/tag.cpp')
-rw-r--r--juk/tag.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/juk/tag.cpp b/juk/tag.cpp
index 27f0a91c..08a717ea 100644
--- a/juk/tag.cpp
+++ b/juk/tag.cpp
@@ -54,9 +54,9 @@ Tag::Tag(const TQString &fileName) :
m_bitrate(0),
m_isValid(false)
{
- // using qDebug here since we want this to show up in non-debug builds as well
+ // using tqDebug here since we want this to show up in non-debug builds as well
- qDebug("Reading tag for %s", fileName.local8Bit().data());
+ tqDebug("Reading tag for %s", fileName.local8Bit().data());
if(MediaFiles::isMP3(fileName)) {
TagLib::MPEG::File file(TQFile::encodeName(fileName).data());